# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLevelSetsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkSegmentationLevelSetImageFilterPython
else:
    import _itkSegmentationLevelSetImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkSparseFieldLevelSetImageFilterPython
import itk.itkFiniteDifferenceImageFilterPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterBPython
import itk.itkImageRegionPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkImageSourcePython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterAPython
import itk.itkFiniteDifferenceFunctionPython
import itk.itkSegmentationLevelSetFunctionPython
import itk.itkLevelSetFunctionPython
class itkSegmentationLevelSetImageFilterIF2IF2F(itk.itkSparseFieldLevelSetImageFilterPython.itkSparseFieldLevelSetImageFilterIF2IF2):
    r"""Proxy of C++ itkSegmentationLevelSetImageFilterIF2IF2F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetMaximumIterations(self, i):
        r"""
        SetMaximumIterations(self, i)

        Parameters
        ----------
        i: unsigned int

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetMaximumIterations(self, i)

    def GetMaximumIterations(self):
        r"""GetMaximumIterations(self) -> unsigned int"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetMaximumIterations(self)

    def SetFeatureImage(self, f):
        r"""
        SetFeatureImage(self, f)

        Parameters
        ----------
        f: itkImageF2 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetFeatureImage(self, f)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF2"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetFeatureImage(self)

    def SetInitialImage(self, _arg):
        r"""
        SetInitialImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetInitialImage(self, _arg)

    def GetInitialImage(self):
        r"""GetInitialImage(self) -> itkImageF2"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetInitialImage(self)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetInput2(self, input)

    def SetSpeedImage(self, s):
        r"""
        SetSpeedImage(self, s)

        Parameters
        ----------
        s: itkImageF2 *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetSpeedImage(self, s)

    def SetAdvectionImage(self, v):
        r"""
        SetAdvectionImage(self, v)

        Parameters
        ----------
        v: itkImageFAF22 *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetAdvectionImage(self, v)

    def GetSpeedImage(self):
        r"""GetSpeedImage(self) -> itkImageF2"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetSpeedImage(self)

    def GetAdvectionImage(self):
        r"""GetAdvectionImage(self) -> itkImageFAF22"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetAdvectionImage(self)

    def SetUseNegativeFeaturesOn(self):
        r"""SetUseNegativeFeaturesOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetUseNegativeFeaturesOn(self)

    def SetUseNegativeFeaturesOff(self):
        r"""SetUseNegativeFeaturesOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetUseNegativeFeaturesOff(self)

    def SetUseNegativeFeatures(self, u):
        r"""
        SetUseNegativeFeatures(self, u)

        Parameters
        ----------
        u: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetUseNegativeFeatures(self, u)

    def GetUseNegativeFeatures(self):
        r"""GetUseNegativeFeatures(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetUseNegativeFeatures(self)

    def SetReverseExpansionDirection(self, _arg):
        r"""
        SetReverseExpansionDirection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetReverseExpansionDirection(self, _arg)

    def GetReverseExpansionDirection(self):
        r"""GetReverseExpansionDirection(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetReverseExpansionDirection(self)

    def ReverseExpansionDirectionOn(self):
        r"""ReverseExpansionDirectionOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_ReverseExpansionDirectionOn(self)

    def ReverseExpansionDirectionOff(self):
        r"""ReverseExpansionDirectionOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_ReverseExpansionDirectionOff(self)

    def SetAutoGenerateSpeedAdvection(self, _arg):
        r"""
        SetAutoGenerateSpeedAdvection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetAutoGenerateSpeedAdvection(self, _arg)

    def GetAutoGenerateSpeedAdvection(self):
        r"""GetAutoGenerateSpeedAdvection(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetAutoGenerateSpeedAdvection(self)

    def AutoGenerateSpeedAdvectionOn(self):
        r"""AutoGenerateSpeedAdvectionOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_AutoGenerateSpeedAdvectionOn(self)

    def AutoGenerateSpeedAdvectionOff(self):
        r"""AutoGenerateSpeedAdvectionOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_AutoGenerateSpeedAdvectionOff(self)

    def SetFeatureScaling(self, v):
        r"""
        SetFeatureScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetFeatureScaling(self, v)

    def SetPropagationScaling(self, v):
        r"""
        SetPropagationScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetPropagationScaling(self, v)

    def GetPropagationScaling(self):
        r"""GetPropagationScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetPropagationScaling(self)

    def SetAdvectionScaling(self, v):
        r"""
        SetAdvectionScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetAdvectionScaling(self, v)

    def GetAdvectionScaling(self):
        r"""GetAdvectionScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetAdvectionScaling(self)

    def SetCurvatureScaling(self, v):
        r"""
        SetCurvatureScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetCurvatureScaling(self, v)

    def GetCurvatureScaling(self):
        r"""GetCurvatureScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetCurvatureScaling(self)

    def SetUseMinimalCurvature(self, b):
        r"""
        SetUseMinimalCurvature(self, b)

        Parameters
        ----------
        b: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetUseMinimalCurvature(self, b)

    def GetUseMinimalCurvature(self):
        r"""GetUseMinimalCurvature(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetUseMinimalCurvature(self)

    def UseMinimalCurvatureOn(self):
        r"""UseMinimalCurvatureOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_UseMinimalCurvatureOn(self)

    def UseMinimalCurvatureOff(self):
        r"""UseMinimalCurvatureOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_UseMinimalCurvatureOff(self)

    def SetSegmentationFunction(self, s):
        r"""
        SetSegmentationFunction(self, s)

        Parameters
        ----------
        s: itkSegmentationLevelSetFunctionIF2IF2 *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetSegmentationFunction(self, s)

    def GetSegmentationFunction(self):
        r"""GetSegmentationFunction(self) -> itkSegmentationLevelSetFunctionIF2IF2"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetSegmentationFunction(self)

    def SetMaximumCurvatureTimeStep(self, n):
        r"""
        SetMaximumCurvatureTimeStep(self, n)

        Parameters
        ----------
        n: double

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetMaximumCurvatureTimeStep(self, n)

    def GetMaximumCurvatureTimeStep(self):
        r"""GetMaximumCurvatureTimeStep(self) -> double"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetMaximumCurvatureTimeStep(self)

    def SetMaximumPropagationTimeStep(self, n):
        r"""
        SetMaximumPropagationTimeStep(self, n)

        Parameters
        ----------
        n: double

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_SetMaximumPropagationTimeStep(self, n)

    def GetMaximumPropagationTimeStep(self):
        r"""GetMaximumPropagationTimeStep(self) -> double"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GetMaximumPropagationTimeStep(self)

    def GenerateSpeedImage(self):
        r"""GenerateSpeedImage(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GenerateSpeedImage(self)

    def GenerateAdvectionImage(self):
        r"""GenerateAdvectionImage(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_GenerateAdvectionImage(self)
    OutputHasNumericTraitsCheck = _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkSegmentationLevelSetImageFilterPython.delete_itkSegmentationLevelSetImageFilterIF2IF2F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSegmentationLevelSetImageFilterIF2IF2F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_cast(obj)

# Register itkSegmentationLevelSetImageFilterIF2IF2F in _itkSegmentationLevelSetImageFilterPython:
_itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F_swigregister(itkSegmentationLevelSetImageFilterIF2IF2F)
class itkSegmentationLevelSetImageFilterIF2IVF22F(itk.itkSparseFieldLevelSetImageFilterPython.itkSparseFieldLevelSetImageFilterIF2IF2):
    r"""Proxy of C++ itkSegmentationLevelSetImageFilterIF2IVF22F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetMaximumIterations(self, i):
        r"""
        SetMaximumIterations(self, i)

        Parameters
        ----------
        i: unsigned int

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetMaximumIterations(self, i)

    def GetMaximumIterations(self):
        r"""GetMaximumIterations(self) -> unsigned int"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetMaximumIterations(self)

    def SetFeatureImage(self, f):
        r"""
        SetFeatureImage(self, f)

        Parameters
        ----------
        f: itkImageVF22 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetFeatureImage(self, f)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageVF22"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetFeatureImage(self)

    def SetInitialImage(self, _arg):
        r"""
        SetInitialImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetInitialImage(self, _arg)

    def GetInitialImage(self):
        r"""GetInitialImage(self) -> itkImageF2"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetInitialImage(self)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageVF22 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetInput2(self, input)

    def SetSpeedImage(self, s):
        r"""
        SetSpeedImage(self, s)

        Parameters
        ----------
        s: itkImageF2 *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetSpeedImage(self, s)

    def SetAdvectionImage(self, v):
        r"""
        SetAdvectionImage(self, v)

        Parameters
        ----------
        v: itkImageFAF22 *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetAdvectionImage(self, v)

    def GetSpeedImage(self):
        r"""GetSpeedImage(self) -> itkImageF2"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetSpeedImage(self)

    def GetAdvectionImage(self):
        r"""GetAdvectionImage(self) -> itkImageFAF22"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetAdvectionImage(self)

    def SetUseNegativeFeaturesOn(self):
        r"""SetUseNegativeFeaturesOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetUseNegativeFeaturesOn(self)

    def SetUseNegativeFeaturesOff(self):
        r"""SetUseNegativeFeaturesOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetUseNegativeFeaturesOff(self)

    def SetUseNegativeFeatures(self, u):
        r"""
        SetUseNegativeFeatures(self, u)

        Parameters
        ----------
        u: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetUseNegativeFeatures(self, u)

    def GetUseNegativeFeatures(self):
        r"""GetUseNegativeFeatures(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetUseNegativeFeatures(self)

    def SetReverseExpansionDirection(self, _arg):
        r"""
        SetReverseExpansionDirection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetReverseExpansionDirection(self, _arg)

    def GetReverseExpansionDirection(self):
        r"""GetReverseExpansionDirection(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetReverseExpansionDirection(self)

    def ReverseExpansionDirectionOn(self):
        r"""ReverseExpansionDirectionOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_ReverseExpansionDirectionOn(self)

    def ReverseExpansionDirectionOff(self):
        r"""ReverseExpansionDirectionOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_ReverseExpansionDirectionOff(self)

    def SetAutoGenerateSpeedAdvection(self, _arg):
        r"""
        SetAutoGenerateSpeedAdvection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetAutoGenerateSpeedAdvection(self, _arg)

    def GetAutoGenerateSpeedAdvection(self):
        r"""GetAutoGenerateSpeedAdvection(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetAutoGenerateSpeedAdvection(self)

    def AutoGenerateSpeedAdvectionOn(self):
        r"""AutoGenerateSpeedAdvectionOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_AutoGenerateSpeedAdvectionOn(self)

    def AutoGenerateSpeedAdvectionOff(self):
        r"""AutoGenerateSpeedAdvectionOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_AutoGenerateSpeedAdvectionOff(self)

    def SetFeatureScaling(self, v):
        r"""
        SetFeatureScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetFeatureScaling(self, v)

    def SetPropagationScaling(self, v):
        r"""
        SetPropagationScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetPropagationScaling(self, v)

    def GetPropagationScaling(self):
        r"""GetPropagationScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetPropagationScaling(self)

    def SetAdvectionScaling(self, v):
        r"""
        SetAdvectionScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetAdvectionScaling(self, v)

    def GetAdvectionScaling(self):
        r"""GetAdvectionScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetAdvectionScaling(self)

    def SetCurvatureScaling(self, v):
        r"""
        SetCurvatureScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetCurvatureScaling(self, v)

    def GetCurvatureScaling(self):
        r"""GetCurvatureScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetCurvatureScaling(self)

    def SetUseMinimalCurvature(self, b):
        r"""
        SetUseMinimalCurvature(self, b)

        Parameters
        ----------
        b: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetUseMinimalCurvature(self, b)

    def GetUseMinimalCurvature(self):
        r"""GetUseMinimalCurvature(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetUseMinimalCurvature(self)

    def UseMinimalCurvatureOn(self):
        r"""UseMinimalCurvatureOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_UseMinimalCurvatureOn(self)

    def UseMinimalCurvatureOff(self):
        r"""UseMinimalCurvatureOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_UseMinimalCurvatureOff(self)

    def SetSegmentationFunction(self, s):
        r"""
        SetSegmentationFunction(self, s)

        Parameters
        ----------
        s: itk::SegmentationLevelSetFunction< itk::Image< float >,itk::Image< itk::Vector< float,2 > > > *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetSegmentationFunction(self, s)

    def GetSegmentationFunction(self):
        r"""GetSegmentationFunction(self) -> itk::SegmentationLevelSetFunction< itk::Image< float >,itk::Image< itk::Vector< float,2 > > > *"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetSegmentationFunction(self)

    def SetMaximumCurvatureTimeStep(self, n):
        r"""
        SetMaximumCurvatureTimeStep(self, n)

        Parameters
        ----------
        n: double

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetMaximumCurvatureTimeStep(self, n)

    def GetMaximumCurvatureTimeStep(self):
        r"""GetMaximumCurvatureTimeStep(self) -> double"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetMaximumCurvatureTimeStep(self)

    def SetMaximumPropagationTimeStep(self, n):
        r"""
        SetMaximumPropagationTimeStep(self, n)

        Parameters
        ----------
        n: double

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_SetMaximumPropagationTimeStep(self, n)

    def GetMaximumPropagationTimeStep(self):
        r"""GetMaximumPropagationTimeStep(self) -> double"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GetMaximumPropagationTimeStep(self)

    def GenerateSpeedImage(self):
        r"""GenerateSpeedImage(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GenerateSpeedImage(self)

    def GenerateAdvectionImage(self):
        r"""GenerateAdvectionImage(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_GenerateAdvectionImage(self)
    OutputHasNumericTraitsCheck = _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkSegmentationLevelSetImageFilterPython.delete_itkSegmentationLevelSetImageFilterIF2IVF22F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSegmentationLevelSetImageFilterIF2IVF22F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_cast(obj)

# Register itkSegmentationLevelSetImageFilterIF2IVF22F in _itkSegmentationLevelSetImageFilterPython:
_itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IVF22F_swigregister(itkSegmentationLevelSetImageFilterIF2IVF22F)
class itkSegmentationLevelSetImageFilterIF3IF3F(itk.itkSparseFieldLevelSetImageFilterPython.itkSparseFieldLevelSetImageFilterIF3IF3):
    r"""Proxy of C++ itkSegmentationLevelSetImageFilterIF3IF3F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetMaximumIterations(self, i):
        r"""
        SetMaximumIterations(self, i)

        Parameters
        ----------
        i: unsigned int

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetMaximumIterations(self, i)

    def GetMaximumIterations(self):
        r"""GetMaximumIterations(self) -> unsigned int"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetMaximumIterations(self)

    def SetFeatureImage(self, f):
        r"""
        SetFeatureImage(self, f)

        Parameters
        ----------
        f: itkImageF3 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetFeatureImage(self, f)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF3"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetFeatureImage(self)

    def SetInitialImage(self, _arg):
        r"""
        SetInitialImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetInitialImage(self, _arg)

    def GetInitialImage(self):
        r"""GetInitialImage(self) -> itkImageF3"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetInitialImage(self)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetInput2(self, input)

    def SetSpeedImage(self, s):
        r"""
        SetSpeedImage(self, s)

        Parameters
        ----------
        s: itkImageF3 *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetSpeedImage(self, s)

    def SetAdvectionImage(self, v):
        r"""
        SetAdvectionImage(self, v)

        Parameters
        ----------
        v: itkImageFAF33 *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetAdvectionImage(self, v)

    def GetSpeedImage(self):
        r"""GetSpeedImage(self) -> itkImageF3"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetSpeedImage(self)

    def GetAdvectionImage(self):
        r"""GetAdvectionImage(self) -> itkImageFAF33"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetAdvectionImage(self)

    def SetUseNegativeFeaturesOn(self):
        r"""SetUseNegativeFeaturesOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetUseNegativeFeaturesOn(self)

    def SetUseNegativeFeaturesOff(self):
        r"""SetUseNegativeFeaturesOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetUseNegativeFeaturesOff(self)

    def SetUseNegativeFeatures(self, u):
        r"""
        SetUseNegativeFeatures(self, u)

        Parameters
        ----------
        u: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetUseNegativeFeatures(self, u)

    def GetUseNegativeFeatures(self):
        r"""GetUseNegativeFeatures(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetUseNegativeFeatures(self)

    def SetReverseExpansionDirection(self, _arg):
        r"""
        SetReverseExpansionDirection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetReverseExpansionDirection(self, _arg)

    def GetReverseExpansionDirection(self):
        r"""GetReverseExpansionDirection(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetReverseExpansionDirection(self)

    def ReverseExpansionDirectionOn(self):
        r"""ReverseExpansionDirectionOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_ReverseExpansionDirectionOn(self)

    def ReverseExpansionDirectionOff(self):
        r"""ReverseExpansionDirectionOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_ReverseExpansionDirectionOff(self)

    def SetAutoGenerateSpeedAdvection(self, _arg):
        r"""
        SetAutoGenerateSpeedAdvection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetAutoGenerateSpeedAdvection(self, _arg)

    def GetAutoGenerateSpeedAdvection(self):
        r"""GetAutoGenerateSpeedAdvection(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetAutoGenerateSpeedAdvection(self)

    def AutoGenerateSpeedAdvectionOn(self):
        r"""AutoGenerateSpeedAdvectionOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_AutoGenerateSpeedAdvectionOn(self)

    def AutoGenerateSpeedAdvectionOff(self):
        r"""AutoGenerateSpeedAdvectionOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_AutoGenerateSpeedAdvectionOff(self)

    def SetFeatureScaling(self, v):
        r"""
        SetFeatureScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetFeatureScaling(self, v)

    def SetPropagationScaling(self, v):
        r"""
        SetPropagationScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetPropagationScaling(self, v)

    def GetPropagationScaling(self):
        r"""GetPropagationScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetPropagationScaling(self)

    def SetAdvectionScaling(self, v):
        r"""
        SetAdvectionScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetAdvectionScaling(self, v)

    def GetAdvectionScaling(self):
        r"""GetAdvectionScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetAdvectionScaling(self)

    def SetCurvatureScaling(self, v):
        r"""
        SetCurvatureScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetCurvatureScaling(self, v)

    def GetCurvatureScaling(self):
        r"""GetCurvatureScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetCurvatureScaling(self)

    def SetUseMinimalCurvature(self, b):
        r"""
        SetUseMinimalCurvature(self, b)

        Parameters
        ----------
        b: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetUseMinimalCurvature(self, b)

    def GetUseMinimalCurvature(self):
        r"""GetUseMinimalCurvature(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetUseMinimalCurvature(self)

    def UseMinimalCurvatureOn(self):
        r"""UseMinimalCurvatureOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_UseMinimalCurvatureOn(self)

    def UseMinimalCurvatureOff(self):
        r"""UseMinimalCurvatureOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_UseMinimalCurvatureOff(self)

    def SetSegmentationFunction(self, s):
        r"""
        SetSegmentationFunction(self, s)

        Parameters
        ----------
        s: itkSegmentationLevelSetFunctionIF3IF3 *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetSegmentationFunction(self, s)

    def GetSegmentationFunction(self):
        r"""GetSegmentationFunction(self) -> itkSegmentationLevelSetFunctionIF3IF3"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetSegmentationFunction(self)

    def SetMaximumCurvatureTimeStep(self, n):
        r"""
        SetMaximumCurvatureTimeStep(self, n)

        Parameters
        ----------
        n: double

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetMaximumCurvatureTimeStep(self, n)

    def GetMaximumCurvatureTimeStep(self):
        r"""GetMaximumCurvatureTimeStep(self) -> double"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetMaximumCurvatureTimeStep(self)

    def SetMaximumPropagationTimeStep(self, n):
        r"""
        SetMaximumPropagationTimeStep(self, n)

        Parameters
        ----------
        n: double

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_SetMaximumPropagationTimeStep(self, n)

    def GetMaximumPropagationTimeStep(self):
        r"""GetMaximumPropagationTimeStep(self) -> double"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GetMaximumPropagationTimeStep(self)

    def GenerateSpeedImage(self):
        r"""GenerateSpeedImage(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GenerateSpeedImage(self)

    def GenerateAdvectionImage(self):
        r"""GenerateAdvectionImage(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_GenerateAdvectionImage(self)
    OutputHasNumericTraitsCheck = _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkSegmentationLevelSetImageFilterPython.delete_itkSegmentationLevelSetImageFilterIF3IF3F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSegmentationLevelSetImageFilterIF3IF3F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_cast(obj)

# Register itkSegmentationLevelSetImageFilterIF3IF3F in _itkSegmentationLevelSetImageFilterPython:
_itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F_swigregister(itkSegmentationLevelSetImageFilterIF3IF3F)
class itkSegmentationLevelSetImageFilterIF3IVF33F(itk.itkSparseFieldLevelSetImageFilterPython.itkSparseFieldLevelSetImageFilterIF3IF3):
    r"""Proxy of C++ itkSegmentationLevelSetImageFilterIF3IVF33F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetMaximumIterations(self, i):
        r"""
        SetMaximumIterations(self, i)

        Parameters
        ----------
        i: unsigned int

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetMaximumIterations(self, i)

    def GetMaximumIterations(self):
        r"""GetMaximumIterations(self) -> unsigned int"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetMaximumIterations(self)

    def SetFeatureImage(self, f):
        r"""
        SetFeatureImage(self, f)

        Parameters
        ----------
        f: itkImageVF33 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetFeatureImage(self, f)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageVF33"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetFeatureImage(self)

    def SetInitialImage(self, _arg):
        r"""
        SetInitialImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetInitialImage(self, _arg)

    def GetInitialImage(self):
        r"""GetInitialImage(self) -> itkImageF3"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetInitialImage(self)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageVF33 const *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetInput2(self, input)

    def SetSpeedImage(self, s):
        r"""
        SetSpeedImage(self, s)

        Parameters
        ----------
        s: itkImageF3 *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetSpeedImage(self, s)

    def SetAdvectionImage(self, v):
        r"""
        SetAdvectionImage(self, v)

        Parameters
        ----------
        v: itkImageFAF33 *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetAdvectionImage(self, v)

    def GetSpeedImage(self):
        r"""GetSpeedImage(self) -> itkImageF3"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetSpeedImage(self)

    def GetAdvectionImage(self):
        r"""GetAdvectionImage(self) -> itkImageFAF33"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetAdvectionImage(self)

    def SetUseNegativeFeaturesOn(self):
        r"""SetUseNegativeFeaturesOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetUseNegativeFeaturesOn(self)

    def SetUseNegativeFeaturesOff(self):
        r"""SetUseNegativeFeaturesOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetUseNegativeFeaturesOff(self)

    def SetUseNegativeFeatures(self, u):
        r"""
        SetUseNegativeFeatures(self, u)

        Parameters
        ----------
        u: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetUseNegativeFeatures(self, u)

    def GetUseNegativeFeatures(self):
        r"""GetUseNegativeFeatures(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetUseNegativeFeatures(self)

    def SetReverseExpansionDirection(self, _arg):
        r"""
        SetReverseExpansionDirection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetReverseExpansionDirection(self, _arg)

    def GetReverseExpansionDirection(self):
        r"""GetReverseExpansionDirection(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetReverseExpansionDirection(self)

    def ReverseExpansionDirectionOn(self):
        r"""ReverseExpansionDirectionOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_ReverseExpansionDirectionOn(self)

    def ReverseExpansionDirectionOff(self):
        r"""ReverseExpansionDirectionOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_ReverseExpansionDirectionOff(self)

    def SetAutoGenerateSpeedAdvection(self, _arg):
        r"""
        SetAutoGenerateSpeedAdvection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetAutoGenerateSpeedAdvection(self, _arg)

    def GetAutoGenerateSpeedAdvection(self):
        r"""GetAutoGenerateSpeedAdvection(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetAutoGenerateSpeedAdvection(self)

    def AutoGenerateSpeedAdvectionOn(self):
        r"""AutoGenerateSpeedAdvectionOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_AutoGenerateSpeedAdvectionOn(self)

    def AutoGenerateSpeedAdvectionOff(self):
        r"""AutoGenerateSpeedAdvectionOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_AutoGenerateSpeedAdvectionOff(self)

    def SetFeatureScaling(self, v):
        r"""
        SetFeatureScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetFeatureScaling(self, v)

    def SetPropagationScaling(self, v):
        r"""
        SetPropagationScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetPropagationScaling(self, v)

    def GetPropagationScaling(self):
        r"""GetPropagationScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetPropagationScaling(self)

    def SetAdvectionScaling(self, v):
        r"""
        SetAdvectionScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetAdvectionScaling(self, v)

    def GetAdvectionScaling(self):
        r"""GetAdvectionScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetAdvectionScaling(self)

    def SetCurvatureScaling(self, v):
        r"""
        SetCurvatureScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetCurvatureScaling(self, v)

    def GetCurvatureScaling(self):
        r"""GetCurvatureScaling(self) -> float"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetCurvatureScaling(self)

    def SetUseMinimalCurvature(self, b):
        r"""
        SetUseMinimalCurvature(self, b)

        Parameters
        ----------
        b: bool

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetUseMinimalCurvature(self, b)

    def GetUseMinimalCurvature(self):
        r"""GetUseMinimalCurvature(self) -> bool"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetUseMinimalCurvature(self)

    def UseMinimalCurvatureOn(self):
        r"""UseMinimalCurvatureOn(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_UseMinimalCurvatureOn(self)

    def UseMinimalCurvatureOff(self):
        r"""UseMinimalCurvatureOff(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_UseMinimalCurvatureOff(self)

    def SetSegmentationFunction(self, s):
        r"""
        SetSegmentationFunction(self, s)

        Parameters
        ----------
        s: itk::SegmentationLevelSetFunction< itk::Image< float,3 >,itk::Image< itk::Vector< float >,3 > > *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetSegmentationFunction(self, s)

    def GetSegmentationFunction(self):
        r"""GetSegmentationFunction(self) -> itk::SegmentationLevelSetFunction< itk::Image< float,3 >,itk::Image< itk::Vector< float >,3 > > *"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetSegmentationFunction(self)

    def SetMaximumCurvatureTimeStep(self, n):
        r"""
        SetMaximumCurvatureTimeStep(self, n)

        Parameters
        ----------
        n: double

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetMaximumCurvatureTimeStep(self, n)

    def GetMaximumCurvatureTimeStep(self):
        r"""GetMaximumCurvatureTimeStep(self) -> double"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetMaximumCurvatureTimeStep(self)

    def SetMaximumPropagationTimeStep(self, n):
        r"""
        SetMaximumPropagationTimeStep(self, n)

        Parameters
        ----------
        n: double

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_SetMaximumPropagationTimeStep(self, n)

    def GetMaximumPropagationTimeStep(self):
        r"""GetMaximumPropagationTimeStep(self) -> double"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GetMaximumPropagationTimeStep(self)

    def GenerateSpeedImage(self):
        r"""GenerateSpeedImage(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GenerateSpeedImage(self)

    def GenerateAdvectionImage(self):
        r"""GenerateAdvectionImage(self)"""
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_GenerateAdvectionImage(self)
    OutputHasNumericTraitsCheck = _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_OutputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkSegmentationLevelSetImageFilterPython.delete_itkSegmentationLevelSetImageFilterIF3IVF33F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkSegmentationLevelSetImageFilterIF3IVF33F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_cast(obj)

# Register itkSegmentationLevelSetImageFilterIF3IVF33F in _itkSegmentationLevelSetImageFilterPython:
_itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IVF33F_swigregister(itkSegmentationLevelSetImageFilterIF3IVF33F)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def segmentation_level_set_image_filter(*args: itkt.ImageLike,  maximum_iterations: int=..., feature_image: itkt.Image=..., initial_image: itkt.Image=..., speed_image: itkt.Image=..., advection_image: itkt.Image=..., use_negative_features: bool=..., reverse_expansion_direction: bool=..., auto_generate_speed_advection: bool=..., feature_scaling: float=..., propagation_scaling: float=..., advection_scaling: float=..., curvature_scaling: float=..., use_minimal_curvature: bool=..., segmentation_function=..., maximum_curvature_time_step: float=..., maximum_propagation_time_step: float=..., number_of_layers: int=..., iso_surface_value: float=..., interpolate_surface_location: bool=..., difference_function=..., number_of_iterations: int=..., use_image_spacing: bool=..., maximum_rms_error: float=..., rms_change: float=..., manual_reinitialization: bool=..., is_initialized: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for SegmentationLevelSetImageFilter"""
    import itk

    kwarg_typehints = { 'maximum_iterations':maximum_iterations,'feature_image':feature_image,'initial_image':initial_image,'speed_image':speed_image,'advection_image':advection_image,'use_negative_features':use_negative_features,'reverse_expansion_direction':reverse_expansion_direction,'auto_generate_speed_advection':auto_generate_speed_advection,'feature_scaling':feature_scaling,'propagation_scaling':propagation_scaling,'advection_scaling':advection_scaling,'curvature_scaling':curvature_scaling,'use_minimal_curvature':use_minimal_curvature,'segmentation_function':segmentation_function,'maximum_curvature_time_step':maximum_curvature_time_step,'maximum_propagation_time_step':maximum_propagation_time_step,'number_of_layers':number_of_layers,'iso_surface_value':iso_surface_value,'interpolate_surface_location':interpolate_surface_location,'difference_function':difference_function,'number_of_iterations':number_of_iterations,'use_image_spacing':use_image_spacing,'maximum_rms_error':maximum_rms_error,'rms_change':rms_change,'manual_reinitialization':manual_reinitialization,'is_initialized':is_initialized }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.SegmentationLevelSetImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def segmentation_level_set_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLevelSets.SegmentationLevelSetImageFilter
    segmentation_level_set_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    segmentation_level_set_image_filter.__doc__ = filter_object.__doc__



